---
title: Outlines
hide:
  - navigation
  - toc
  - feedback
---

#

<figure markdown>
  ![Image title](assets/images/logo.png){ width="300" }
</figure>

<center>
    <h1 class="title">Generate text with LLMs</h1>
    <h2 class="subtitle">Robust prompting & (guided) text generation</h2>
    [:fontawesome-solid-bolt: Get started](welcome.md){ .md-button .md-button--primary }
    [:fontawesome-brands-discord: Join the Community](https://discord.gg/ZxBxyWmW5n){ .md-button }

<div class="index-pre-code">
```bash
pip install outlines
```
</div>
</center>
